@@ -822,19 +822,6 @@ function can remove it, such as with `denote-file-prompt-group'."
                 (propertize (or (denote-retrieve-filename-keywords file) "") 'face 'completions-annotations)))))
    files))
 
-(defun denote-sequence-file-prompt-group (file transform)
-  "Retun group of FILE if TRANSFORM is non-nil, per `completion-metadata'."
-  (cond
-   (transform
-    (denote-retrieve-filename-title file))
-   ((string-match-p (regexp-opt denote-encryption-file-extensions) file)
-    "Encrypted")
-   ((string-match-p (regexp-opt (denote-file-type-extensions)) file)
-    "Notes")
-   ((string-match-p "\\.\\(pdf\\|epub\\)" file)
-    "Documents")
-   (t "Other files")))
-
 (defvar denote-sequence-file-prompt-extra-metadata
   (list
    ;; NOTE 2025-12-15: If we use the `file' category, then we are
@@ -842,7 +829,7 @@ function can remove it, such as with `denote-file-prompt-group'."
    ;; problem because the user will want to, for example, sort
    ;; directories before files, but then we cannot have our sort here.
    (cons 'category 'denote-file)
-   (cons 'group-function #'denote-sequence-file-prompt-group)
+   (cons 'group-function #'denote-file-prompt-group)
    (cons 'affixation-function #'denote-sequence-file-prompt-affixate)
    (cons 'display-sort-function #'denote-sequence-sort-files))
   "Extra `completion-metadata' for the `denote-file-prompt'.
@@ -865,7 +852,7 @@ completion candidates.  Else use `denote-sequence-get-all-files'."
          ;; relative file paths of the completion candidates.
          (default-directory (if single-dir-p
                                 (car roots)
-                              (denote-directories-get-common-root roots))))
+                              (denote-directories-get-common-root))))
     (if-let* ((files (or files-with-sequences (denote-sequence-get-all-files)))
               (relative-files (if single-dir-p
                                   (mapcar #'denote-get-file-name-relative-to-denote-directory files)
@@ -1184,13 +1171,12 @@ For a more specialised case, see `denote-sequence-find-relatives-dired'."
                          files-sorted)))))
     (if-let* ((directory (if single-dir-p
                              (car roots)
-                           (denote-directories-get-common-root roots)))
+                           (denote-directories-get-common-root)))
               (files (funcall files-fn))
-              (dired-name (denote-format-buffer-name
+              (buffer-name (denote-format-buffer-name
                            (format-message "prefix `%s'; depth `%s'" (or prefix "ALL") (or depth "ALL"))
-                           :is-special-buffer))
-              (buffer-name dired-name))
-        (denote-sort-dired--prepare-buffer directory files-fn dired-name buffer-name)
+                           :is-special-buffer)))
+        (denote-sort-dired--prepare-buffer directory files-fn buffer-name)
       (message "No matching files"))))
 
 ;;;###autoload
